Class: Etsy::Image

Inherits:
Object
  • Object
show all
Includes:
Model
Defined in:
lib/etsy/image.rb

Overview

Image

Represents an image resource of an Etsy listing and contains multiple sizes. Sizes available are:

[square] The square image thumbnail (75x75 pixels) [small] The small image thumbnail (170x135 pixels) [thumbnail] The thumbnail for the image, no more than 570px wide [full] The full image for this listing, no more than 1500px wide

Class Method Summary collapse

Methods included from Model

included, #initialize, #result, #secret, #token

Class Method Details

.create(listing, image_path, options = {}) ⇒ Object



28
29
30
31
32
# File 'lib/etsy/image.rb', line 28

def self.create(listing, image_path, options = {})
  options[:image] = File.new(image_path)
  options[:multipart] = true
  post("/listings/#{listing.id}/images", options)
end

.find_all_by_listing_id(listing_id) ⇒ Object

Fetch all images for a given listing.



24
25
26
# File 'lib/etsy/image.rb', line 24

def self.find_all_by_listing_id(listing_id)
  get_all("/listings/#{listing_id}/images")
end